@@ -1086,7 +1086,12 @@ class Consul(object):
         def __init__(self, agent):
             self.agent = agent
 
-        def service(self, service, index=None, passing=None, tag=None):
+        def service(self,
+                    service,
+                    index=None,
+                    passing=None,
+                    tag=None,
+                    dc=None):
             """
             Returns a tuple of (*index*, *nodes*)
 
@@ -1099,6 +1104,9 @@ class Consul(object):
             those nodes whose checks are currently passing.
 
             Calling with *tag* will filter the results by tag.
+
+            *dc* is the datacenter of the node and defaults to this agents
+            datacenter.
             """
             params = {}
             if index is not None:
@@ -1107,6 +1115,9 @@ class Consul(object):
                 params['passing'] = '1'
             if tag is not None:
                 params['tag'] = tag
+            dc = dc or self.agent.dc
+            if dc:
+                params['dc'] = dc
 
             def callback(response):
                 data = json.loads(response.body)
@@ -1116,7 +1127,7 @@ class Consul(object):
                 callback,
                 '/v1/health/service/%s' % service, params=params)
 
-        def state(self, name, index=None):
+        def state(self, name, index=None, dc=None):
             """
             Returns a tuple of (*index*, *nodes*)
 
@@ -1129,12 +1140,18 @@ class Consul(object):
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *dc* is the datacenter of the node and defaults to this agents
+            datacenter.
+
             *nodes* are the nodes providing the given service.
             """
             assert name in ['any', 'unknown', 'passing', 'warning', 'critical']
             params = {}
             if index:
                 params['index'] = index
+            dc = dc or self.agent.dc
+            if dc:
+                params['dc'] = dc
 
             def callback(response):
                 data = json.loads(response.body)
@@ -1144,18 +1161,24 @@ class Consul(object):
                 callback,
                 '/v1/health/state/%s' % name, params=params)
 
-        def node(self, node, index=None):
+        def node(self, node, index=None, dc=None):
             """
             Returns a tuple of (*index*, *checks*)
 
             *index* is the current Consul index, suitable for making subsequent
             calls to wait for changes since this query was last run.
 
+            *dc* is the datacenter of the node and defaults to this agents
+            datacenter.
+
             *nodes* are the nodes providing the given service.
             """
             params = {}
             if index:
                 params['index'] = index
+            dc = dc or self.agent.dc
+            if dc:
+                params['dc'] = dc
 
             def callback(response):
                 data = json.loads(response.body)
