@@ -9,10 +9,11 @@ __all__ = ['Consul']
 
 
 class HTTPClient(object):
-    def __init__(self, host='127.0.0.1', port=8500):
+    def __init__(self, host='127.0.0.1', port=8500, scheme='http'):
         self.host = host
         self.port = port
-        self.base_uri = 'http://%s:%s' % (self.host, self.port)
+        self.scheme = scheme
+        self.base_uri = '%s://%s:%s' % (self.scheme, self.host, self.port)
 
     def response(self, response):
         return base.Response(
@@ -38,5 +39,5 @@ class HTTPClient(object):
 
 
 class Consul(base.Consul):
-    def connect(self, host, port):
-        return HTTPClient(host, port)
+    def connect(self, host, port, scheme):
+        return HTTPClient(host, port, scheme)
